************************************
Controlling third party applications
************************************

Existing supported apps
=======================

Phylo apps
----------

Alignment apps
--------------

RNA structure apps
------------------

Visualisation
-------------

PyMol, MAGE
^^^^^^^^^^^

Adding new apps
===============

Pipelining 3rd party apps
=========================

.. integrating with cogent features

.. grab seqs from genbank, align, build tree, cogent evolutionary analysis

